summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrCanvas.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-07 21:14:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-07 21:14:06 +0000
commitafbfdc507bfaafc8824a9808311d57a9ece87510 (patch)
tree47be45bbd69c321ce79e14b683e59318748be9cb /kpresenter/KPrCanvas.h
parent880d042b2902fae8007f202dd35ad9330499867b (diff)
downloadkoffice-afbfdc507bfaafc8824a9808311d57a9ece87510.tar.gz
koffice-afbfdc507bfaafc8824a9808311d57a9ece87510.zip
Rename incorrect instances of tqrepaint[...] to repaint[...]
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240369 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpresenter/KPrCanvas.h')
-rw-r--r--kpresenter/KPrCanvas.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpresenter/KPrCanvas.h b/kpresenter/KPrCanvas.h
index 9ab7de16..c7c67c02 100644
--- a/kpresenter/KPrCanvas.h
+++ b/kpresenter/KPrCanvas.h
@@ -438,7 +438,7 @@ protected:
// functions for displaying
/**
- * This method is used for tqrepainting the canvas.
+ * This method is used for repainting the canvas.
*/
virtual void paintEvent( TQPaintEvent* );
@@ -690,13 +690,13 @@ private:
* If so it returns the position it has snapped to.
*
* @param pos the point which should be snapped
* @param tqrepaintSnapping true if the guides should be tqrepainted.
* @param tqrepaintSnapping false when the guides should not be tqrepainted.
* You have to call tqrepaint by yourself.
*
* @return the position of the snapped point
*/
- KoPoint snapPoint( KoPoint &pos, bool tqrepaintSnapping = true );
+ KoPoint snapPoint( KoPoint &pos, bool repaintSnapping = true );
/**
* @brief Find the next grid in distance
@@ -690,13 +690,13 @@ private:
*
* @param pos the point which should be snapped
- * @param tqrepaintSnapping true if the guides should be tqrepainted.
- * @param tqrepaintSnapping false when the guides should not be tqrepainted.
+ * @param repaintSnapping true if the guides should be repainted.
+ * @param repaintSnapping false when the guides should not be repainted.
* You have to call tqrepaint by yourself.
*